@@ -84,8 +84,8 @@ group_by.tbl_kusto_abstract <- function(.data, ..., add = FALSE)
     {
         return(.data)
     }
-
-    groups <- group_by_prepare(.data, .dots = dots, add = add)
+    # Updated for dplyr deprecation of .dots and add params
+    groups <- group_by_prepare(.data, !!!dots, .add = add)
     names <- vapply(groups$groups, as_string, character(1))
     add_op_single("group_by",
                   groups$data,
@@ -182,6 +182,12 @@ head.tbl_kusto_abstract <- function(x, n = 6L, ...)
     add_op_single("head", x, args = list(n = n))
 }
 
+#' @export
+slice_sample.tbl_kusto_abstract <- function(x, n = 6L, ...)
+{
+    add_op_single("slice_sample", x, args = list(n = n))
+}
+
 #' Join methods for Kusto tables
 #'
 #' These methods are the same as other joining methods, with the exception of the `.strategy`, `.shufflekeys` and `.num_partitions` optional arguments. They provide hints to the Kusto engine on how to execute the join, and can sometimes be useful to speed up a query. See the Kusto documentation for more details.
@@ -395,6 +401,102 @@ compute.tbl_kusto <- function(tbl, name=generate_table_name(), ...)
     invisible(tbl_kusto(tbl$src, name))
 }
 
+#' Execute the query, store the results in a table, and return a reference to the new table
+#' Run a Kusto query and export results to Azure Storage in Parquet or CSV
+#' format.
+#'
+#' @param query The text of the Kusto query to run
+#' @param storage_uri The URI of the blob storage container to export to
+#' @param name_prefix The filename prefix for each exported file
+#' @param key The account key for the storage container.
+#' uses the identity that is signed into Kusto to authenticate to Azure Storage.
+#' @param format Options are "parquet", "csv", "tsv", "json"
+#' @param distributed logical, indicates whether Kusto should distributed the
+#' export job to multiple nodes, in which case multiple files will be written
+#' to storage concurrently.
+kusto_export_cmd <- function(query, storage_uri, name_prefix, key, format,
+    distributed) {
+    # Make sure the storage uri ends with a slash
+    if (!(format %in% c("parquet", "csv", "tsv", "json")))
+        stop("Format must be one of parquet, csv, tsv, or json.")
+    if (!endsWith(storage_uri, "/"))
+        storage_uri <- paste0(storage_uri, "/")
+    distr <- ifelse(distributed, "true", "false")
+    compr <- ifelse(format == "parquet", "snappy", "gzip")
+    sprintf(".export
+compressed
+to %s (h@'%s%s;%s')
+with (
+sizeLimit=1073741824,
+namePrefix='%s',
+fileExtension='%s',
+compressionType='%s',
+includeHeaders='firstFile',
+encoding='UTF8NoBOM',
+distributed=%s
+)
+<|
+%s
+", format, storage_uri, name_prefix, key, name_prefix, format, compr, distr, query)
+}
+
+#' Execute the Kusto query and export the result to Azure Storage.
+#' @param tbl An object representing a table or database.
+#' @param storage_uri The Azure Storage URI to export files to.
+#' @param query A Kusto query string
+#' @param name_prefix The filename prefix to use for exported files.
+#' @param key default "impersonate" which uses the account signed into Kusto to
+#' authenticate to Azure Storage. An Azure Storage account key.
+#' @param format Options are "parquet", "csv", "tsv", "json"
+#' @param distributed logical, indicates whether Kusto should distributed the
+#' export job to multiple nodes, in which case multiple files will be written
+#' to storage concurrently.
+#' @param ... needed for agreement with generic. Not otherwise used.
+#' @rdname export
+#' @export
+export <- function(tbl, storage_uri, query = NULL, name_prefix = "export",
+    key = "impersonate", format = "parquet", distributed = FALSE, ...) {
+    UseMethod("export")
+}
+
+#' Execute the Kusto query and export the result to Azure Storage.
+#' @param tbl A Kusto database endpoint object, as returned by `kusto_database_endpoint`.
+#' @param query A Kusto query string
+#' @param storage_uri The Azure Storage URI to export files to.
+#' @param name_prefix The filename prefix to use for exported files.
+#' @param key default "impersonate" which uses the account signed into Kusto to
+#' authenticate to Azure Storage. An Azure Storage account key.
+#' @param format Options are "parquet", "csv", "tsv", "json"
+#' @param distributed logical, indicates whether Kusto should distributed the
+#' export job to multiple nodes, in which case multiple files will be written
+#' to storage concurrently.
+#' @param ... needed for agreement with generic. Not otherwise used.
+#' @rdname export
+#' @export
+export.kusto_database_endpoint <- function(tbl, storage_uri, query = NULL, name_prefix = "export",
+    key = "impersonate", format = "parquet", distributed = FALSE, ...) {
+    if (missing(query)) stop("query parameter is required.")
+    is_cmd <- substr(query, 1, 1) == "."
+    if (is_cmd) stop("Management commands cannot be used with export()")
+    q_str <- kusto_export_cmd(query = query, storage_uri = storage_uri,
+        name_prefix = name_prefix, key = key, format = format,
+        distributed = distributed)
+    run_query(tbl, q_str, ...)
+}
+
+#' @rdname export
+#' @export
+export.tbl_kusto <- function(tbl, storage_uri, query = NULL, name_prefix = "export",
+    key = "impersonate", format = "parquet", distributed = FALSE, ...) {
+    database <- tbl$src
+    q <- kql_render(kql_build(tbl))
+    q_str <- kusto_export_cmd(query = q, storage_uri = storage_uri,
+        name_prefix = name_prefix, key = key, format = format,
+        distributed = distributed)
+    res <- run_query(database, q_str, ...)
+    tibble::as_tibble(res)
+}
+
 #' @keywords internal
 #' @export
 print.tbl_kusto_abstract <- function(x, ...)
